searchData={"items":[{"type":"module","title":"ExAws.IAM","doc":"Generates ExAws operations for making IAM API requests.\n\nYou can use the low-level `operation/2` to create any operation.\n\n    iex> ExAws.IAM.operation(:list_users, max_items: 50, path: \"/my/path/\")\n    %ExAws.Operation.Query{\n      action: \"ListUsers\",\n      params: %{\n        \"Action\" => \"ListUsers\",\n        \"MaxItems\" => 50,\n        \"Path\" => \"/my/path/\",\n        \"Version\" => \"2010-05-08\"\n      },\n      parser: &ExAws.IAM.Parser.parse/2,\n      path: \"/my/path/\",\n      service: :iam\n    }\n\nYou can also use one of the higher-level convenience functions.\n\n    iex> ExAws.IAM.list_users(max_items: 50, path: \"/my/path/\")\n    %ExAws.Operation.Query{\n      action: \"ListUsers\",\n      params: %{\n        \"Action\" => \"ListUsers\",\n        \"MaxItems\" => 50,\n        \"Path\" => \"/my/path/\",\n        \"Version\" => \"2010-05-08\"\n      },\n      parser: &ExAws.IAM.Parser.parse/2,\n      path: \"/my/path/\",\n      service: :iam\n    }\n\nParsers are currently implemented for the following actions:\n\n  * CreateAccessKey\n  * CreateGroup\n  * CreateUser\n  * DeleteAccessKey\n  * DeleteGroup\n  * DeleteUser\n  * GetAccessKeyLastUsed\n  * GetGroup\n  * GetUser\n  * ListAccessKeys\n  * ListGroup\n  * ListRoles\n  * ListRoleTags\n  * ListUsers\n  * PutUserPolicy\n  * UpdateAccessKey\n  * UpdateGroup\n  * UpdateUser\n\nFor more information on individual actions, see the AWS\nIAM API documentation.\n\n  * https://docs.aws.amazon.com/IAM/latest/APIReference/API_{OpName}.html\n\nReplace `OpName` with the name of the operation you want to consult.","ref":"ExAws.IAM.html"},{"type":"module","title":"Shared Options - ExAws.IAM","doc":"* `:version` - The API version that the request is written for, expressed in the\n    format YYYY-MM-DD. Defaults to `2010-05-08`.\n\n  * `:parser` - A function to parse the request. Defaults to `Parser.parse/2`.","ref":"ExAws.IAM.html#module-shared-options"},{"type":"function","title":"ExAws.IAM.create_access_key/2","doc":"Creates an ExAws operation for a `CreateAccessKey` IAM request.","ref":"ExAws.IAM.html#create_access_key/2"},{"type":"function","title":"Parameters - ExAws.IAM.create_access_key/2","doc":"* `username` - The name of the IAM user that the new key will belong to.","ref":"ExAws.IAM.html#create_access_key/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.create_access_key/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#create_access_key/2-options"},{"type":"function","title":"ExAws.IAM.create_group/2","doc":"Creates an ExAws operation for a `CreateGroup` IAM request.","ref":"ExAws.IAM.html#create_group/2"},{"type":"function","title":"Parameters - ExAws.IAM.create_group/2","doc":"* `name` - The name of the IAM group to create.","ref":"ExAws.IAM.html#create_group/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.create_group/2","doc":"* `:path` - The path to the group. Defaults to \"/\".\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#create_group/2-options"},{"type":"function","title":"ExAws.IAM.create_user/2","doc":"Creates an ExAws operation for a `CreateUser` IAM request.","ref":"ExAws.IAM.html#create_user/2"},{"type":"function","title":"Parameters - ExAws.IAM.create_user/2","doc":"* `username` - The name of the user to create. Must match `[w+=,.@-]+`.","ref":"ExAws.IAM.html#create_user/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.create_user/2","doc":"* `:path` - The path for the user name. See IAM Identifiers in the IAM User Guide.\n\n  * `:permissions_boundary` - The ARN of the policy that is used to set the\n    permissions boundary for the user.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#create_user/2-options"},{"type":"function","title":"ExAws.IAM.delete_access_key/3","doc":"Creates an ExAws operation for a `DeleteAccessKey` IAM request.","ref":"ExAws.IAM.html#delete_access_key/3"},{"type":"function","title":"Parameters - ExAws.IAM.delete_access_key/3","doc":"* `access_key_id` - The access key ID you want to delete.\n\n  * `username` - The name of the user whose access key pair you want to delete.","ref":"ExAws.IAM.html#delete_access_key/3-parameters"},{"type":"function","title":"Options - ExAws.IAM.delete_access_key/3","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#delete_access_key/3-options"},{"type":"function","title":"ExAws.IAM.delete_group/2","doc":"Creates an ExAws operation for a `DeleteGroup` IAM request.","ref":"ExAws.IAM.html#delete_group/2"},{"type":"function","title":"Parameters - ExAws.IAM.delete_group/2","doc":"* `name` - The name of the group to delete.","ref":"ExAws.IAM.html#delete_group/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.delete_group/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#delete_group/2-options"},{"type":"function","title":"ExAws.IAM.delete_user/2","doc":"Creates an ExAws operation for a `DeleteUser` IAM request.","ref":"ExAws.IAM.html#delete_user/2"},{"type":"function","title":"Parameters - ExAws.IAM.delete_user/2","doc":"* `username` - The name of the user to delete.","ref":"ExAws.IAM.html#delete_user/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.delete_user/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#delete_user/2-options"},{"type":"function","title":"ExAws.IAM.get_access_key_last_used/2","doc":"Creates an ExAws operation for a `GetAccessKeyLastUsed` IAM request.","ref":"ExAws.IAM.html#get_access_key_last_used/2"},{"type":"function","title":"Parameters - ExAws.IAM.get_access_key_last_used/2","doc":"* `access_key_id` - The identifier of the access key you want to query.","ref":"ExAws.IAM.html#get_access_key_last_used/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.get_access_key_last_used/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#get_access_key_last_used/2-options"},{"type":"function","title":"ExAws.IAM.get_group/2","doc":"Creates an ExAws operation for a `GetGroup` IAM request.","ref":"ExAws.IAM.html#get_group/2"},{"type":"function","title":"Parameters - ExAws.IAM.get_group/2","doc":"* `name` - The name of the group to return.","ref":"ExAws.IAM.html#get_group/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.get_group/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#get_group/2-options"},{"type":"function","title":"ExAws.IAM.get_user/2","doc":"Creates an ExAws operation for a `GetUser` IAM request.","ref":"ExAws.IAM.html#get_user/2"},{"type":"function","title":"Parameters - ExAws.IAM.get_user/2","doc":"* `username` - The name of the user to return.","ref":"ExAws.IAM.html#get_user/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.get_user/2","doc":"See shared options in moduledoc.","ref":"ExAws.IAM.html#get_user/2-options"},{"type":"function","title":"ExAws.IAM.list_access_keys/1","doc":"Creates an ExAws operation for a `ListAccessKeys` IAM request.","ref":"ExAws.IAM.html#list_access_keys/1"},{"type":"function","title":"Options - ExAws.IAM.list_access_keys/1","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:user_name` - Use this parameter to limit the results to the given username.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#list_access_keys/1-options"},{"type":"function","title":"ExAws.IAM.list_groups/1","doc":"Creates an ExAws operation for a `ListGroups` IAM request.","ref":"ExAws.IAM.html#list_groups/1"},{"type":"function","title":"Options - ExAws.IAM.list_groups/1","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:path_prefix` - The path prefix for filtering the results.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#list_groups/1-options"},{"type":"function","title":"ExAws.IAM.list_role_tags/2","doc":"Creates an ExAws operation for a `ListRoleTags` IAM request.","ref":"ExAws.IAM.html#list_role_tags/2"},{"type":"function","title":"Parameters - ExAws.IAM.list_role_tags/2","doc":"* `role_name` - The name of the role to return for which you want to get the list of tags.","ref":"ExAws.IAM.html#list_role_tags/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.list_role_tags/2","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:path_prefix` - The path prefix for filtering the results.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#list_role_tags/2-options"},{"type":"function","title":"ExAws.IAM.list_roles/1","doc":"Creates an ExAws operation for a `ListRoles` IAM request.","ref":"ExAws.IAM.html#list_roles/1"},{"type":"function","title":"Options - ExAws.IAM.list_roles/1","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:path_prefix` - The path prefix for filtering the results.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#list_roles/1-options"},{"type":"function","title":"ExAws.IAM.list_users/1","doc":"Creates an ExAws operation for a `ListUsers` IAM request.","ref":"ExAws.IAM.html#list_users/1"},{"type":"function","title":"Options - ExAws.IAM.list_users/1","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:path_prefix` - The path prefix for filtering the results.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#list_users/1-options"},{"type":"function","title":"ExAws.IAM.operation/3","doc":"Generates an ExAws operation for the given IAM API action.\n\nSee the AWS IAM API Reference for a list of available actions.\n\n  * https://docs.aws.amazon.com/IAM/latest/APIReference","ref":"ExAws.IAM.html#operation/3"},{"type":"function","title":"Parameters - ExAws.IAM.operation/3","doc":"* `action` - The name of the action you want to call. Should be a _CamelCase_ string.\n\n  * `params` - A keyword list of any params the action takes.","ref":"ExAws.IAM.html#operation/3-parameters"},{"type":"function","title":"Options - ExAws.IAM.operation/3","doc":"Any options that the given action \n\n  * `parser` - A function to parse the request result. Defaults\n    to `Parser.parser/2`.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#operation/3-options"},{"type":"function","title":"ExAws.IAM.put_user_policy/4","doc":"Put a ExAws policy to a user.","ref":"ExAws.IAM.html#put_user_policy/4"},{"type":"function","title":"Parameters - ExAws.IAM.put_user_policy/4","doc":"* `username` - The name of the user to whom the policy will be attached.\n  * `policy_name` - The name of the policy to add or modify.\n  * `policy_document` - The JSON document containing the policy.","ref":"ExAws.IAM.html#put_user_policy/4-parameters"},{"type":"function","title":"Options - ExAws.IAM.put_user_policy/4","doc":"* `:marker` - Use this parameter only when paginating results.\n\n  * `:max_items` - Use this only when paginating results to indicate\n    the maximum number of items you want in the response.\n\n  * `:path_prefix` - The path prefix for filtering the results.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#put_user_policy/4-options"},{"type":"function","title":"ExAws.IAM.to_access_key/1","doc":"Converts a parsed IAM response into an `AccessKey` struct.\n\n  * `resp` - The parsed response of an IAM API query request.","ref":"ExAws.IAM.html#to_access_key/1"},{"type":"function","title":"ExAws.IAM.to_user/1","doc":"Converts a parsed IAM response into a `User` struct.","ref":"ExAws.IAM.html#to_user/1"},{"type":"function","title":"Parameters - ExAws.IAM.to_user/1","doc":"* `resp` - The parsed response of an IAM API query request.","ref":"ExAws.IAM.html#to_user/1-parameters"},{"type":"function","title":"ExAws.IAM.update_access_key/3","doc":"Creates an ExAws operation for an `UpdateAccessKey` IAM request.","ref":"ExAws.IAM.html#update_access_key/3"},{"type":"function","title":"Parameters - ExAws.IAM.update_access_key/3","doc":"* `access_key_id` - The access key ID you want to update.\n\n  * `status` - The status you want to assign to the secret access key.\n    Can be `Active` or `Inactive`.","ref":"ExAws.IAM.html#update_access_key/3-parameters"},{"type":"function","title":"Options - ExAws.IAM.update_access_key/3","doc":"* `:user_name` - The name of the user whose access key pair you want to update.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#update_access_key/3-options"},{"type":"function","title":"ExAws.IAM.update_group/2","doc":"Creates an ExAws operation for an `UpdateGroup` IAM request.","ref":"ExAws.IAM.html#update_group/2"},{"type":"function","title":"Parameters - ExAws.IAM.update_group/2","doc":"* `name` - The name of the group to update. If you're changing the name\n    of the group, this is the original group name.","ref":"ExAws.IAM.html#update_group/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.update_group/2","doc":"* `:new_path` - New path for the IAM group. Include this parameter only\n    if you're changing the group's path.\n\n  * `:new_group_name` - New name for the group. Include this parameter only\n    if you're changing the group's name.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#update_group/2-options"},{"type":"function","title":"ExAws.IAM.update_user/2","doc":"Creates an ExAws operation for an `UpdateUser` IAM request.","ref":"ExAws.IAM.html#update_user/2"},{"type":"function","title":"Parameters - ExAws.IAM.update_user/2","doc":"* `username` - The name of the user to update. If you're changing the name\n    of the user, this is the original user name.","ref":"ExAws.IAM.html#update_user/2-parameters"},{"type":"function","title":"Options - ExAws.IAM.update_user/2","doc":"* `:new_path` - New path for the IAM user. Include this parameter only\n    if you're changing the user's path.\n\n  * `:new_user_name` - New name for the user. Include this parameter only\n    if you're changing the user's name.\n\nSee shared options in moduledoc.","ref":"ExAws.IAM.html#update_user/2-options"},{"type":"module","title":"ExAws.IAM.AccessKey","doc":"A struct that represents an IAM access key.","ref":"ExAws.IAM.AccessKey.html"},{"type":"function","title":"ExAws.IAM.AccessKey.new/1","doc":"Returns a struct representation of an IAM AccessKey.","ref":"ExAws.IAM.AccessKey.html#new/1"},{"type":"type","title":"ExAws.IAM.AccessKey.t/0","doc":"","ref":"ExAws.IAM.AccessKey.html#t:t/0"},{"type":"module","title":"ExAws.IAM.Parser","doc":"An interface for parsing IAM user query responses.\n\nTo add a new parser, define a `parse/2` function in the desired\nmodule and add the action name to the corresponding @x_actions list.\n\nThe first argument should be the XML response body and the\nsecond the name of the operation.","ref":"ExAws.IAM.Parser.html"},{"type":"function","title":"ExAws.IAM.Parser.parse/2","doc":"Parses XML from IAM API query responses.","ref":"ExAws.IAM.Parser.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.AccessKey","doc":"Defines parsers for handling AWS IAM `AccessKey` query reponses.","ref":"ExAws.IAM.Parsers.AccessKey.html"},{"type":"function","title":"ExAws.IAM.Parsers.AccessKey.parse/2","doc":"Parses XML from IAM `ListAccessKeys` response.\nParses XML from IAM `GetAccessKeyLastUsed` response.\nParses XML from IAM `CreateAccessKey` response.","ref":"ExAws.IAM.Parsers.AccessKey.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.Group","doc":"Defines parsers for handling AWS IAM `Group` query reponses.","ref":"ExAws.IAM.Parsers.Group.html"},{"type":"function","title":"ExAws.IAM.Parsers.Group.parse/2","doc":"Parses XML from IAM `ListGroups` response.\nParses XML from IAM `GetGroup` response.\nParses XML from IAM `CreateGroup` response.","ref":"ExAws.IAM.Parsers.Group.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.Metadata","doc":"Defines parsers for handling AWS IAM reponses that\ncontain only metadata.","ref":"ExAws.IAM.Parsers.Metadata.html"},{"type":"function","title":"ExAws.IAM.Parsers.Metadata.parse/2","doc":"A generic parser for responses that contain only metadata.","ref":"ExAws.IAM.Parsers.Metadata.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.Policy","doc":"Defines parsers for handling AWS IAM `Policy` query reponses.","ref":"ExAws.IAM.Parsers.Policy.html"},{"type":"function","title":"ExAws.IAM.Parsers.Policy.parse/2","doc":"Parses XML from IAM `PutUserPolicy` response.","ref":"ExAws.IAM.Parsers.Policy.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.Role","doc":"Defines parsers for handling AWS IAM `Role` query reponses.","ref":"ExAws.IAM.Parsers.Role.html"},{"type":"function","title":"ExAws.IAM.Parsers.Role.parse/2","doc":"Parses XML from IAM `ListRoles` response.\nParses XML from IAM `ListRoleTags` response.","ref":"ExAws.IAM.Parsers.Role.html#parse/2"},{"type":"module","title":"ExAws.IAM.Parsers.User","doc":"Defines parsers for handling AWS IAM `User` query reponses.","ref":"ExAws.IAM.Parsers.User.html"},{"type":"function","title":"ExAws.IAM.Parsers.User.parse/2","doc":"Parses XML from IAM `ListUsers` response.\nParses XML from IAM `GetUser` response.\nParses XML from IAM `CreateUser` response.","ref":"ExAws.IAM.Parsers.User.html#parse/2"},{"type":"module","title":"ExAws.IAM.User","doc":"A struct that represents an IAM user.","ref":"ExAws.IAM.User.html"},{"type":"function","title":"ExAws.IAM.User.new/1","doc":"Returns a struct representation of an IAM User.","ref":"ExAws.IAM.User.html#new/1"},{"type":"type","title":"ExAws.IAM.User.t/0","doc":"","ref":"ExAws.IAM.User.html#t:t/0"},{"type":"extras","title":"ExAws IAM","doc":"# ExAws IAM","ref":"readme.html"},{"type":"extras","title":"This is a fork of the library ExAws.IAM available at https://github.com/abitdodgy/ex_aws_iam with added PutUserPolicy function. - ExAws IAM","doc":"Easily interact with the AWS IAM API to work with users, access keys, and any other entity. This is an IAM service module for [ExAws](https://github.com/ex-aws/ex_aws).\n\nThe lib provides a low-level `operation/3` function to build any IAM API action.\n\n```elixir\nop = IAM.operation(:list_users, max_items: 50, path: \"/my/path/\")\n%ExAws.Operation.Query{\n  action: \"ListUsers\",\n  params: %{\n    \"Action\" => \"ListUsers\",\n    \"MaxItems\" => 50,\n    \"Path\" => \"/my/path/\",\n    \"Version\" => \"2010-05-08\"\n  },\n  parser: &ExAws.IAM.Parser.parse/2,\n  path: \"/my/path/\",\n  service: :iam\n}\n\nresp = ExAws.request(op)\n{:ok,\n %{\n   body: %{\n     list_users_result: %{\n       is_truncated: \"false\",\n       users: [\n         %{\n           arn: \"arn:aws:iam::085326204011:user/my/path/abitdodgy\",\n           create_date: \"2018-10-17T00:09:19Z\",\n           path: \"/my/path/\",\n           user_id: \"AIDAIAPPW7ERTKFL2R3TI\",\n           user_name: \"abitdodgy\"\n         }\n       ]\n     },\n     response_metadata: %{request_id: \"25c67fa6-d212-11e8-b8d6-a7951e68fc2c\"}\n   },\n   status_code: 200\n }}\n```\n\nThe lib also provides higher-level convenience functions for interacting with specific services.\n\n```elixir\nop = IAM.create_user(\"my_user\", path: \"/my/path\")\n%ExAws.Operation.Query{\n  action: \"CreateUser\",\n  params: %{\n    \"Action\" => \"CreateUser\",\n    \"Path\" => \"/my/path\",\n    \"UserName\" => \"my_user\",\n    \"Version\" => \"2010-05-08\"\n  },\n  parser: &ExAws.IAM.Parser.parse/2,\n  path: \"/my/path\",\n  service: :iam\n}\n```\n\nYou can also return entity structs.\n\n```\nuser =\n  op\n  |> ExAws.request()\n  |> IAM.to_user()\n\n%IAM.User{\n  arn: \"arn:aws:iam::085326204011:user/my_user\",\n  create_date: \"2018-10-17T13:36:28Z\",\n  path: \"/my/path/\",\n  user_name: \"my_user\",\n  user_id: \"AIDAJMIUVQAU2TW666HH2\"\n}\n\nIAM.delete_user(\"my_user\")\n```\n\nParsers are currently implemented for the following actions:\n\n  * CreateAccessKey\n  * CreateGroup\n  * CreateUser\n  * DeleteAccessKey\n  * DeleteGroup\n  * DeleteUser\n  * GetAccessKeyLastUsed\n  * GetGroup\n  * GetUser\n  * ListAccessKeys\n  * ListGroup\n  * ListRoles\n  * ListRoleTags\n  * ListUsers\n  * PutUserPolicy\n  * UpdateAccessKey\n  * UpdateGroup\n  * UpdateUser\n\nYou can also provider your own parser as long as it implements a `parse/2` function.\n\n```elixir\nIAM.operation(:list_users, parser: &MyParser.parse/2)\n```","ref":"readme.html#this-is-a-fork-of-the-library-exaws-iam-available-at-https-github-com-abitdodgy-ex_aws_iam-with-added-putuserpolicy-function"},{"type":"extras","title":"Installation - ExAws IAM","doc":"Ensure that both `ex_aws`, its dependencies, and `ex_aws_iam` are in your list of dependencies.\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.5\"},\n    {:ex_aws_iam, \"~> 1.0\"}\n  ]\nend\n```\n\nEnsure that ExAws is properly configured.\n\n```\nconfig :ex_aws,\n  access_key_id: [{:system, \"AWS_ACCESS_KEY_ID\"}, :instance_role],\n  secret_access_key: [{:system, \"AWS_SECRET_ACCESS_KEY\"}, :instance_role]\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExAws IAM","doc":"[See the documentation](https://hexdocs.pm/ex_aws_iam/ExAws.IAM.html) for details.","ref":"readme.html#usage"},{"type":"extras","title":"License - ExAws IAM","doc":"The MIT License\n\nCopyright (c) 2018 Mohamad El-Husseini\n\nPermission is hereby granted, free of charge, \nto any person obtaining a copy of this software and \nassociated documentation files (the \"Software\"), to \ndeal in the Software without restriction, including \nwithout limitation the rights to use, copy, modify, \nmerge, publish, distribute, sublicense, and/or sell \ncopies of the Software, and to permit persons to whom \nthe Software is furnished to do so, \nsubject to the following conditions:\n\nThe above copyright notice and this permission notice \nshall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, \nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES \nOF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. \nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR \nANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, \nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE \nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}